---
title: <span class="badge builder"></span> RowsHeatmapOptions
---
# <span class="badge builder"></span> RowsHeatmapOptions

## Constructor

```python
RowsHeatmapOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.RowsHeatmapOptions
```

### <span class="badge object-method"></span> layout

Controls tick alignment when not calculating from data

```python
def layout(layout: common.HeatmapCellLayout) -> typing.Self
```

### <span class="badge object-method"></span> value

Sets the name of the cell when not calculating from data

```python
def value(value: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [RowsHeatmapOptions](./object-RowsHeatmapOptions.md)
